@@ -177,7 +177,7 @@ class Resources(str, enum.Enum):
 
     Task = "tasks"
     """
-    .. deprecated::
+    .. deprecated:: 0.5.0
 
         The Task resource no longer exists, but removing this enum entry
         breaks existing API keys.
@@ -362,16 +362,59 @@ class InferenceServiceSources(str, enum.Enum):
 
 
 class APIFunctions(str, enum.Enum):
+    """Categories of API operations to which access can be granted."""
+
     consume = "consume"
+    """Use the resource as a dependency in another workflow.
+
+    Example: running an ``Evaluation`` on a ``Dataset`` requires ``consume``
+    permission for the ``Dataset``.
+    """
+
     create = "create"
+    """Create a new instance of the resource.
+
+    For resources that require uploading artifacts (such as ``Dataset``), also
+    grants access to the ``upload`` and ``finalize`` endpoints.
+    """
+
     get = "get"
+    """Retrieve a single resource instance by ID."""
+
     query = "query"
+    """Query the resource collection."""
+
     download = "download"
+    """
+    .. deprecated:: 0.5.0
+
+        This functionality has been consolidated into ``data``.
+    """
+
     upload = "upload"
+    """
+    .. deprecated:: 0.5.0
+
+        This functionality has been consolidated into ``create``.
+    """
+
     data = "data"
+    """Download the raw data associated with the resource."""
+
     strata = "strata"
+    """
+    .. deprecated:: 0.5.0
+
+        Similar functionality will be added in the future but with a different
+        interface.
+    """
+
     terminate = "terminate"
+    """Set the resource status to ``Terminated``."""
+
     delete = "delete"
+    """Set the resource status to ``Deleted``."""
+
     all = "*"
 
 
@@ -409,13 +452,19 @@ class APIKey(DyffSchemaBaseModel):
     cryptographically signed APIKey.
     """
 
-    id: str = pydantic.Field(description="Unique ID of the resource")
+    id: str = pydantic.Field(
+        description="Unique ID of the resource. Maps to JWT 'jti' claim."
+    )
     # TODO: Needs validator
     subject: str = pydantic.Field(
-        description="Subject of access grants ('<kind>/<id>')"
+        description="Subject of access grants ('<kind>/<id>'). Maps to JWT 'sub' claim."
+    )
+    created: datetime = pydantic.Field(
+        description="When the APIKey was created. Maps to JWT 'iat' claim."
+    )
+    expires: datetime = pydantic.Field(
+        description="When the APIKey expires. Maps to JWT 'exp' claim."
     )
-    created: datetime = pydantic.Field(description="When the APIKey was created")
-    expires: datetime = pydantic.Field(description="When the APIKey expires")
     secret: Optional[str] = pydantic.Field(
         default=None,
         description="For account keys: a secret value to check when verifying the APIKey",
